@@ -41,6 +41,8 @@
 #include "libgimp/gimpfeatures.h"
 #include "libgimp/gimpenv.h"
 
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "app_procs.h"
 #include "batch.h"
@@ -53,7 +55,6 @@
 #include "errorconsole.h"
 #include "fileops.h"
 #include "gdisplay.h"
-#include "gdisplay_color.h"
 #include "gdisplay_ops.h"
 #include "gimpbrushlist.h"
 #include "gimprc.h"
@@ -90,6 +91,10 @@
 #include "docindex.h"
 #include "colormap_dialog.h"
 
+#ifdef DISPLAY_FILTERS
+#include "gdisplay_color.h"
+#endif /* DISPLAY_FILTERS */
+
 #include "color_notebook.h"
 #include "color_select.h"
 #include "gimpparasite.h"
@@ -117,8 +122,8 @@ static void      splash_logo_expose                   (GtkWidget *widget);
 static void      toast_old_temp_files                 (void);
 
 
-static gint is_app_exit_finish_done = FALSE;
-gint        we_are_exiting          = FALSE;
+static gboolean is_app_exit_finish_done = FALSE;
+gboolean        we_are_exiting          = FALSE;
 
 static GtkWidget *logo_area   = NULL;
 static GdkPixmap *logo_pixmap = NULL;
@@ -131,8 +136,8 @@ static gint max_label_length  = MAXPATHLEN;
 
 
 void
-gimp_init (int    gimp_argc,
-	   char **gimp_argv)
+gimp_init (gint    gimp_argc,
+	   gchar **gimp_argv)
 {
   /* Initialize the application */
   app_init ();
@@ -162,7 +167,7 @@ splash_logo_load_size (GtkWidget *window)
   if (logo_pixmap)
     return TRUE;
 
-  g_snprintf (buf, sizeof(buf), "%s" G_DIR_SEPARATOR_S "gimp1_1_splash.ppm",
+  g_snprintf (buf, sizeof(buf), "%s" G_DIR_SEPARATOR_S "gimp_splash.ppm",
 	      gimp_data_directory ());
 
   fp = fopen (buf, "rb");
@@ -199,7 +204,7 @@ splash_logo_load (GtkWidget *window)
   if (logo_pixmap)
     return TRUE;
 
-  g_snprintf (buf, sizeof(buf), "%s" G_DIR_SEPARATOR_S "gimp1_1_splash.ppm",
+  g_snprintf (buf, sizeof(buf), "%s" G_DIR_SEPARATOR_S "gimp_splash.ppm",
 	      gimp_data_directory ());
 
   fp = fopen (buf, "rb");
@@ -261,18 +266,35 @@ splash_logo_load (GtkWidget *window)
 static void
 splash_text_draw (GtkWidget *widget)
 {
-  GdkFont *font = NULL;
+  GdkFont *font;
 
+  /* this is a font, provide only one single font definition */
   font = gdk_font_load (_("-*-helvetica-bold-r-normal--*-140-*-*-*-*-*-*"));
+  if (!font)
+    {
+      GtkStyle *style = gtk_widget_get_style (widget);
+      font = style->font;
+      gdk_font_ref (font);
+    }
+  
   gdk_draw_string (widget->window,
 		   font,
 		   widget->style->fg_gc[GTK_STATE_NORMAL],
 		   ((logo_area_width - gdk_string_width (font,  _("The GIMP"))) / 2),
 		   (0.25 * logo_area_height),
 		   _("The GIMP"));
-  gdk_font_unref (font);
 
+  gdk_font_unref (font);
+  
+  /* this is a fontset, e.g. multiple comma-separated font definitions */
   font = gdk_fontset_load (_("-*-helvetica-bold-r-normal--*-120-*-*-*-*-*-*,*"));
+  if (!font)
+    {
+      GtkStyle *style = gtk_widget_get_style (widget);
+      font = style->font;
+      gdk_font_ref (font);
+    }
+
   gdk_draw_string (widget->window,
 		   font,
 		   widget->style->fg_gc[GTK_STATE_NORMAL],
@@ -291,6 +313,7 @@ splash_text_draw (GtkWidget *widget)
 		   ((logo_area_width - gdk_string_width (font, AUTHORS)) / 2),
 		   (0.80 * logo_area_height),
 		   AUTHORS);
+
   gdk_font_unref (font);
 }
 
@@ -343,75 +366,72 @@ destroy_initialization_status_window (void)
 static void
 make_initialization_status_window (void)
 {
-  if (!no_interface && !no_splash)
+  GtkWidget *vbox;
+  GtkWidget *logo_hbox;
+  GtkStyle  *style;
+
+  if (no_interface || no_splash)
+    return;
+
+  win_initstatus = gtk_window_new (GTK_WINDOW_DIALOG);
+
+  gtk_window_set_title (GTK_WINDOW (win_initstatus), _("GIMP Startup"));
+  gtk_window_set_wmclass (GTK_WINDOW (win_initstatus), "gimp_startup", "Gimp");
+  gtk_window_set_position (GTK_WINDOW (win_initstatus), GTK_WIN_POS_CENTER);
+  gtk_window_set_policy (GTK_WINDOW (win_initstatus), FALSE, FALSE, FALSE);
+
+  gimp_dialog_set_icon (GTK_WINDOW (win_initstatus));
+
+  if (no_splash_image == FALSE &&
+      splash_logo_load_size (win_initstatus))
     {
-      GtkWidget *vbox;
-      GtkWidget *logo_hbox;
-      GtkStyle  *style;
-
-      win_initstatus = gtk_window_new (GTK_WINDOW_DIALOG);
-
-      gtk_window_set_title (GTK_WINDOW (win_initstatus),                      
-			    _("GIMP Startup"));
-      gtk_window_set_wmclass (GTK_WINDOW (win_initstatus),
-			      "gimp_startup", "Gimp");
-      gtk_window_set_position (GTK_WINDOW (win_initstatus), GTK_WIN_POS_CENTER);
-      gtk_window_set_policy (GTK_WINDOW (win_initstatus), FALSE, FALSE, FALSE);
-
-      gimp_dialog_set_icon (GTK_WINDOW (win_initstatus));
-
-      if (no_splash_image == FALSE &&
-	  splash_logo_load_size (win_initstatus))
-	{
-	  show_logo = SHOW_LATER;
-	}
-
-      vbox = gtk_vbox_new (FALSE, 4);
-      gtk_container_add (GTK_CONTAINER (win_initstatus), vbox);
-
-      logo_hbox = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX(vbox), logo_hbox, FALSE, TRUE, 0);
-
-      logo_area = gtk_drawing_area_new ();
-
-      gtk_signal_connect (GTK_OBJECT (logo_area), "expose_event",
-			  GTK_SIGNAL_FUNC (splash_logo_expose),
-			  NULL);
-
-      logo_area_width  = MAX (logo_width, LOGO_WIDTH_MIN);
-      logo_area_height = MAX (logo_height, LOGO_HEIGHT_MIN);
-
-      gtk_drawing_area_size (GTK_DRAWING_AREA (logo_area),
-			     logo_area_width, logo_area_height);
-      gtk_box_pack_start (GTK_BOX(logo_hbox), logo_area, TRUE, FALSE, 0);
-
-      label1 = gtk_label_new ("");
-      gtk_box_pack_start_defaults (GTK_BOX (vbox), label1);
-      label2 = gtk_label_new ("");
-      gtk_box_pack_start_defaults (GTK_BOX (vbox), label2);
-
-      pbar = gtk_progress_bar_new ();
-      gtk_box_pack_start_defaults (GTK_BOX (vbox), pbar);
-
-      gtk_widget_show (vbox);
-      gtk_widget_show (logo_hbox);
-      gtk_widget_show (logo_area);
-      gtk_widget_show (label1);
-      gtk_widget_show (label2);
-      gtk_widget_show (pbar);
-
-      gtk_widget_show (win_initstatus);
-
-      /*  This is a hack: we try to compute a good guess for the maximum 
-       *  number of charcters that will fit into the splash-screen using 
-       *  the default_font
-       */
-      style = gtk_widget_get_style (win_initstatus);
-      max_label_length =
-	0.8 * (float)strlen (AUTHORS) *
-	((float)logo_area_width /
-	 (float)gdk_string_width (style->font, AUTHORS));
+      show_logo = SHOW_LATER;
     }
+
+  vbox = gtk_vbox_new (FALSE, 4);
+  gtk_container_add (GTK_CONTAINER (win_initstatus), vbox);
+
+  logo_hbox = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), logo_hbox, FALSE, TRUE, 0);
+
+  logo_area = gtk_drawing_area_new ();
+
+  gtk_signal_connect (GTK_OBJECT (logo_area), "expose_event",
+		      GTK_SIGNAL_FUNC (splash_logo_expose),
+		      NULL);
+
+  logo_area_width  = MAX (logo_width, LOGO_WIDTH_MIN);
+  logo_area_height = MAX (logo_height, LOGO_HEIGHT_MIN);
+
+  gtk_drawing_area_size (GTK_DRAWING_AREA (logo_area),
+			 logo_area_width, logo_area_height);
+  gtk_box_pack_start (GTK_BOX(logo_hbox), logo_area, TRUE, FALSE, 0);
+
+  label1 = gtk_label_new ("");
+  gtk_box_pack_start_defaults (GTK_BOX (vbox), label1);
+  label2 = gtk_label_new ("");
+  gtk_box_pack_start_defaults (GTK_BOX (vbox), label2);
+
+  pbar = gtk_progress_bar_new ();
+  gtk_box_pack_start_defaults (GTK_BOX (vbox), pbar);
+
+  gtk_widget_show (vbox);
+  gtk_widget_show (logo_hbox);
+  gtk_widget_show (logo_area);
+  gtk_widget_show (label1);
+  gtk_widget_show (label2);
+  gtk_widget_show (pbar);
+
+  gtk_widget_show (win_initstatus);
+
+  /*  This is a hack: we try to compute a good guess for the maximum 
+   *  number of charcters that will fit into the splash-screen using 
+   *  the default_font
+   */
+  style = gtk_widget_get_style (win_initstatus);
+  max_label_length = (0.8 * (gfloat) strlen (AUTHORS) *
+		      ((gfloat) logo_area_width /
+		       (gfloat) gdk_string_width (style->font, AUTHORS)));
 }
 
 void
@@ -424,7 +444,7 @@ app_init_update_status (gchar *label1val,
   if (!no_interface && !no_splash && win_initstatus)
     {
       if (label1val && strcmp (label1val, GTK_LABEL (label1)->label))
-	gtk_label_set (GTK_LABEL (label1), label1val);
+	gtk_label_set_text (GTK_LABEL (label1), label1val);
 
       if (label2val && strcmp (label2val, GTK_LABEL (label2)->label))
 	{
@@ -468,13 +488,30 @@ app_init (void)
   gchar *filename;
   gchar *path;
 
+  /*  parse the systemwide gtkrc  */
   filename = gimp_gtkrc ();
 
-  if (be_verbose || no_splash)
+  if (be_verbose)
     g_print (_("parsing \"%s\"\n"), filename);
 
   gtk_rc_parse (filename);
 
+  /*  parse the user gtkrc  */
+  filename = gimp_personal_rc_file ("gtkrc");
+
+  if (be_verbose)
+    g_print (_("parsing \"%s\"\n"), filename);
+
+  gtk_rc_parse (filename);
+
+  g_free (filename);
+
+  if (parse_buffers_init ())
+    {
+      parse_unitrc ();   /*  this needs to be done before gimprc loading  */
+      parse_gimprc ();   /*  parse the local GIMP configuration file      */
+    }
+
   if (!no_interface)
     get_standard_colormaps ();
 
@@ -497,13 +534,11 @@ app_init (void)
   RESET_BAR();
   internal_procs_init ();
 
+#ifdef DISPLAY_FILTERS
   color_display_init ();
+#endif /* DISPLAY_FILTERS */
 
   RESET_BAR();
-  parse_buffers_init ();
-  parse_unitrc ();         /*  this needs to be done before gimprc loading  */
-  parse_gimprc ();         /*  parse the local GIMP configuration file      */
-
   if (always_restore_session)
     restore_session = TRUE;
 
@@ -573,15 +608,15 @@ app_init (void)
        *  elements of the docindex
        */
       {
-	FILE *fp;
+	FILE   *fp;
 	gchar **filenames = g_new (gchar *, last_opened_size);
-	gint dummy, i;
+	gint    i;
 
-	if ((fp = idea_manager_parse_init (&dummy, &dummy, &dummy, &dummy)))
+	if ((fp = document_index_parse_init ()))
 	  {
 	    /*  read the filenames...  */
 	    for (i = 0; i < last_opened_size; i++)
-	      if ((filenames[i] = idea_manager_parse_line (fp)) == NULL)
+	      if ((filenames[i] = document_index_parse_line (fp)) == NULL)
 		break;
 
 	    /*  ...and add them in reverse order  */
@@ -603,8 +638,7 @@ app_init (void)
       /*  EEK: force signal emission  */
       if (gimp_context_get_tool (gimp_context_get_user ()) == RECT_SELECT)
 	{
-	  gtk_signal_emit_by_name (GTK_OBJECT (gimp_context_get_user ()),
-				   "tool_changed", RECT_SELECT);
+	  gimp_context_tool_changed (gimp_context_get_user ());
 	}
       else
 	{
@@ -679,15 +713,17 @@ app_exit_finish (void)
   if (!no_interface)
     {
       toolbox_free ();
-      close_idea_window ();
+      document_index_free ();
       gximage_free ();
       render_free ();
       tool_options_dialog_free ();
       save_sessionrc ();
     }
 
-  /* gtk_exit (0); */
-  gtk_main_quit();
+  /*  There used to be gtk_main_quit() here, but there's a chance 
+   *  that gtk_main() was never called before we reach this point. --Sven  
+   */
+  gtk_exit (0);   
 }
 
 void
@@ -705,7 +741,7 @@ app_exit (gboolean kill_it)
  *************************************************/
 
 static void
-really_quit_callback (GtkButton *button,
+really_quit_callback (GtkWidget *button,
 		      gboolean   quit,
 		      gpointer   data)
 {
