@@ -15,6 +15,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
+#include <glib.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "color_balance.h"
 #include "color_transfer.h"
@@ -23,7 +30,6 @@
 #include "gimpui.h"
 #include "image_map.h"
 
-#include "config.h"
 #include "libgimp/gimpintl.h"
 #include "libgimp/gimpmath.h"
 #include "libgimp/gimpcolorspace.h"
@@ -147,8 +153,7 @@ color_balance_control (Tool       *tool,
       break;
 
     case HALT:
-      if (color_balance_dialog)
-	color_balance_cancel_callback (NULL, (gpointer) color_balance_dialog);
+      color_balance_dialog_hide ();
       break;
 
     default:
@@ -170,7 +175,7 @@ tools_new_color_balance (void)
     }
 
   tool = tools_new_tool (COLOR_BALANCE);
-  private = g_new (ColorBalance, 1);
+  private = g_new0 (ColorBalance, 1);
 
   tool->scroll_lock = TRUE;   /*  Disallow scrolling  */
   tool->preserve    = FALSE;  /*  Don't preserve on drawable change  */
@@ -182,6 +187,13 @@ tools_new_color_balance (void)
   return tool;
 }
 
+void
+color_balance_dialog_hide (void)
+{
+  if (color_balance_dialog)
+    color_balance_cancel_callback (NULL, (gpointer) color_balance_dialog);
+} 
+
 void
 tools_free_color_balance (Tool *tool)
 {
@@ -190,8 +202,7 @@ tools_free_color_balance (Tool *tool)
   color_bal = (ColorBalance *) tool->private;
 
   /*  Close the color select dialog  */
-  if (color_balance_dialog)
-    color_balance_cancel_callback (NULL, (gpointer) color_balance_dialog);
+  color_balance_dialog_hide ();
 
   g_free (color_bal);
 }
