@@ -15,12 +15,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
 #include <stdlib.h>
 #include <string.h>
+
+#include <glib.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "draw_core.h"
 #include "edit_selection.h"
 #include "errors.h"
+#include "floating_sel.h"
 #include "free_select.h"
 #include "gimage_mask.h"
 #include "gdisplay.h"
@@ -30,6 +39,7 @@
 
 #include "libgimp/gimpmath.h"
 
+
 #define DEFAULT_MAX_INC  1024
 #define SUPERSAMPLE      3
 #define SUPERSAMPLE2     9
@@ -39,10 +49,15 @@
 typedef struct _FreeSelect FreeSelect;
 struct _FreeSelect
 {
-  DrawCore * core;       /*  Core select object                      */
+  DrawCore  *core;      /*  Core select object                      */
 
-  int        op;         /*  selection operation (ADD, SUB, etc)     */
-  int        num_pts;    /*  Number of points in the polygon         */
+  SelectOps  op;        /*  selection operation (ADD, SUB, etc)     */
+
+  gint      current_x;  /*  these values are updated on every motion event  */
+  gint      current_y;  /*  (enables immediate cursor updating on modifier
+			 *   key events).  */
+
+  gint      num_pts;    /*  Number of points in the polygon         */
 };
 
 
@@ -51,16 +66,16 @@ struct _FreeSelect
 static SelectionOptions * free_options = NULL;
 
 /*  The global array of XPoints for drawing the polygon...  */
-static GdkPoint *         global_pts = NULL;
-static int                max_segs = 0;
+static GdkPoint *global_pts = NULL;
+static gint      max_segs = 0;
 
 
 /*  functions  */
 
-static int
-add_point (int num_pts,
-	   int x,
-	   int y)
+static gint
+add_point (gint num_pts,
+	   gint x,
+	   gint y)
 {
   if (num_pts >= max_segs)
     {
@@ -80,17 +95,17 @@ add_point (int num_pts,
 
 
 static Channel *
-scan_convert (GimpImage       *gimage,
-	      int              num_pts,
+scan_convert (GimpImage        *gimage,
+	      gint              num_pts,
 	      ScanConvertPoint *pts,
-	      int              width,
-	      int              height,
-	      int              antialias)
+	      gint              width,
+	      gint              height,
+	      gboolean          antialias)
 {
-  Channel * mask;
+  Channel       *mask;
   ScanConverter *sc;
 
-  sc = scan_converter_new (width, height, antialias? SUPERSAMPLE : 1);
+  sc = scan_converter_new (width, height, antialias ? SUPERSAMPLE : 1);
   scan_converter_add_points (sc, num_pts, pts);
 
   mask = scan_converter_to_channel (sc, gimage);
@@ -104,24 +119,25 @@ scan_convert (GimpImage       *gimage,
 /*  Polygonal selection apparatus    */
 
 void
-free_select (GImage          *gimage,
-	     int              num_pts,
+free_select (GImage           *gimage,
+	     gint              num_pts,
 	     ScanConvertPoint *pts,
-	     int              op,
-	     int              antialias,
-	     int              feather,
-	     double           feather_radius)
+	     SelectOps         op,
+	     gboolean          antialias,
+	     gboolean          feather,
+	     gdouble           feather_radius)
 {
   Channel *mask;
 
   /*  if applicable, replace the current selection  */
   /*  or insure that a floating selection is anchored down...  */
-  if (op == REPLACE)
+  if (op == SELECTION_REPLACE)
     gimage_mask_clear (gimage);
   else
     gimage_mask_undo (gimage);
 
-  mask = scan_convert (gimage, num_pts, pts, gimage->width, gimage->height, antialias);
+  mask = scan_convert (gimage, num_pts, pts,
+		       gimage->width, gimage->height, antialias);
 
   if (mask)
     {
@@ -142,7 +158,7 @@ free_select_button_press (Tool           *tool,
 			  GdkEventButton *bevent,
 			  gpointer        gdisp_ptr)
 {
-  GDisplay *gdisp;
+  GDisplay   *gdisp;
   FreeSelect *free_sel;
 
   gdisp = (GDisplay *) gdisp_ptr;
@@ -158,14 +174,16 @@ free_select_button_press (Tool           *tool,
   tool->gdisp_ptr = gdisp_ptr;
 
   switch (free_sel->op)
-  {
-   case SELECTION_MOVE_MASK:
-     init_edit_selection (tool, gdisp_ptr, bevent, MaskTranslate);
-     return;
-   case SELECTION_MOVE:
-     init_edit_selection (tool, gdisp_ptr, bevent, MaskToLayerTranslate);
-     return;
-  }
+    {
+    case SELECTION_MOVE_MASK:
+      init_edit_selection (tool, gdisp_ptr, bevent, EDIT_MASK_TRANSLATE);
+      return;
+    case SELECTION_MOVE:
+      init_edit_selection (tool, gdisp_ptr, bevent, EDIT_MASK_TO_LAYER_TRANSLATE);
+      return;
+    default:
+      break;
+    }
 
   add_point (0, bevent->x, bevent->y);
   free_sel->num_pts = 1;
@@ -180,10 +198,10 @@ free_select_button_release (Tool           *tool,
 			    GdkEventButton *bevent,
 			    gpointer        gdisp_ptr)
 {
-  FreeSelect *free_sel;
+  FreeSelect       *free_sel;
   ScanConvertPoint *pts;
-  GDisplay *gdisp;
-  int i;
+  GDisplay         *gdisp;
+  gint              i;
 
   gdisp = (GDisplay *) gdisp_ptr;
   free_sel = (FreeSelect *) tool->private;
@@ -198,7 +216,20 @@ free_select_button_release (Tool           *tool,
   /*  First take care of the case where the user "cancels" the action  */
   if (! (bevent->state & GDK_BUTTON3_MASK))
     {
-      pts = (ScanConvertPoint *) g_malloc (sizeof (ScanConvertPoint) * free_sel->num_pts);
+      if (free_sel->op == SELECTION_ANCHOR)
+	{
+	  /*  If there is a floating selection, anchor it  */
+	  if (gimage_floating_sel (gdisp->gimage))
+	    floating_sel_anchor (gimage_floating_sel (gdisp->gimage));
+	  /*  Otherwise, clear the selection mask  */
+	  else
+	    gimage_mask_clear (gdisp->gimage);
+	  
+	  gdisplays_flush ();
+	  return;
+	}
+
+      pts = g_new (ScanConvertPoint, free_sel->num_pts);
 
       for (i = 0; i < free_sel->num_pts; i++)
 	{
@@ -222,13 +253,24 @@ free_select_motion (Tool           *tool,
 		    gpointer        gdisp_ptr)
 {
   FreeSelect *free_sel;
-  GDisplay *gdisp;
+  GDisplay   *gdisp;
+
+  gdisp = (GDisplay *) gdisp_ptr;
+  free_sel = (FreeSelect *) tool->private;
+
+  /*  needed for immediate cursor update on modifier event  */
+  free_sel->current_x = mevent->x;
+  free_sel->current_y = mevent->y;
 
   if (tool->state != ACTIVE)
     return;
 
-  gdisp = (GDisplay *) gdisp_ptr;
-  free_sel = (FreeSelect *) tool->private;
+  if (free_sel->op == SELECTION_ANCHOR)
+    {
+      free_sel->op = SELECTION_REPLACE;
+
+      rect_select_cursor_update (tool, mevent, gdisp_ptr);
+    }
 
   if (add_point (free_sel->num_pts, mevent->x, mevent->y))
     {
@@ -247,21 +289,21 @@ free_select_control (Tool       *tool,
 		     ToolAction  action,
 		     gpointer    gdisp_ptr)
 {
-  FreeSelect * free_sel;
+  FreeSelect *free_sel;
 
   free_sel = (FreeSelect *) tool->private;
 
   switch (action)
     {
-    case PAUSE :
+    case PAUSE:
       draw_core_pause (free_sel->core, tool);
       break;
 
-    case RESUME :
+    case RESUME:
       draw_core_resume (free_sel->core, tool);
       break;
 
-    case HALT :
+    case HALT:
       draw_core_stop (free_sel->core, tool);
       break;
 
@@ -273,8 +315,8 @@ free_select_control (Tool       *tool,
 void
 free_select_draw (Tool *tool)
 {
-  FreeSelect * free_sel;
-  int i;
+  FreeSelect *free_sel;
+  gint        i;
 
   free_sel = (FreeSelect *) tool->private;
 
@@ -285,7 +327,7 @@ free_select_draw (Tool *tool)
 }
 
 static void
-free_select_options_reset ()
+free_select_options_reset (void)
 {
   selection_options_reset (free_options);
 }
@@ -293,8 +335,8 @@ free_select_options_reset ()
 Tool *
 tools_new_free_select (void)
 {
-  Tool * tool;
-  FreeSelect * private;
+  Tool       *tool;
+  FreeSelect *private;
 
   /*  The tool options  */
   if (!free_options)
@@ -305,11 +347,11 @@ tools_new_free_select (void)
     }
 
   tool = tools_new_tool (FREE_SELECT);
-  private = g_new (FreeSelect, 1);
+  private = g_new0 (FreeSelect, 1);
 
-  private->core = draw_core_new (free_select_draw);
+  private->core    = draw_core_new (free_select_draw);
   private->num_pts = 0;
-  private->op = SELECTION_REPLACE;
+  private->op      = SELECTION_REPLACE;
 
   tool->scroll_lock = TRUE;   /*  Do not allow scrolling  */
 
@@ -318,6 +360,7 @@ tools_new_free_select (void)
   tool->button_press_func   = free_select_button_press;
   tool->button_release_func = free_select_button_release;
   tool->motion_func         = free_select_motion;
+  tool->modifier_key_func   = rect_select_modifier_update;
   tool->cursor_update_func  = rect_select_cursor_update;
   tool->oper_update_func    = rect_select_oper_update;
   tool->control_func        = free_select_control;
@@ -328,7 +371,7 @@ tools_new_free_select (void)
 void
 tools_free_free_select (Tool *tool)
 {
-  FreeSelect * free_sel;
+  FreeSelect *free_sel;
 
   free_sel = (FreeSelect *) tool->private;
 
