@@ -15,7 +15,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
 #include <stdlib.h>
+
+#include <glib.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "drawable.h"
 #include "image_new.h"
@@ -23,6 +31,7 @@
 #include "gdisplay.h"
 #include "gimage.h"
 #include "gimage_mask.h"
+#include "gimprc.h"
 #include "gimpui.h"
 #include "global_edit.h"
 #include "layer.h"
@@ -30,7 +39,6 @@
 #include "tools.h"
 #include "undo.h"
 
-#include "config.h"
 #include "libgimp/gimpintl.h"
 
 #include "tile_manager_pvt.h"
@@ -192,7 +200,7 @@ edit_cut (GImage       *gimage,
   empty = gimage_mask_is_empty (gimage);
 
   /*  Next, cut the mask portion from the gimage  */
-  cut = gimage_mask_extract (gimage, drawable, TRUE, FALSE);
+  cut = gimage_mask_extract (gimage, drawable, TRUE, FALSE, TRUE);
 
   /*  Only crop if the gimage mask wasn't empty  */
   if (cut && empty == FALSE)
@@ -243,7 +251,7 @@ edit_copy (GImage       *gimage,
   empty = gimage_mask_is_empty (gimage);
 
   /*  First, copy the masked portion of the gimage  */
-  copy = gimage_mask_extract (gimage, drawable, FALSE, FALSE);
+  copy = gimage_mask_extract (gimage, drawable, FALSE, FALSE, TRUE);
 
   /*  Only crop if the gimage mask wasn't empty  */
   if (copy && empty == FALSE)
@@ -359,6 +367,7 @@ edit_paste_as_new (GImage      *invoke,
   GImage   *gimage;
   Layer    *layer;
   GDisplay *gdisp;
+  GimpParasite *comment_parasite;
 
   if (!global_buf)
     return FALSE;
@@ -369,6 +378,16 @@ edit_paste_as_new (GImage      *invoke,
   gimp_image_set_resolution (gimage, invoke->xresolution, invoke->yresolution);
   gimp_image_set_unit (gimage, invoke->unit);
   
+  if (default_comment)
+    {
+      comment_parasite = gimp_parasite_new ("gimp-comment",
+					    GIMP_PARASITE_PERSISTENT,
+					    strlen (default_comment) + 1,
+					    (gpointer) default_comment);
+      gimp_image_parasite_attach (gimage, comment_parasite);
+      gimp_parasite_free (comment_parasite);
+    }
+  
   layer = layer_new_from_tiles (gimage,
 				gimp_image_base_type_with_alpha (gimage),
 				paste, 
@@ -432,7 +451,8 @@ edit_clear (GImage       *gimage,
 
 gboolean
 edit_fill (GImage       *gimage,
-	   GimpDrawable *drawable)
+	   GimpDrawable *drawable,
+	   GimpFillType  fill_type)
 {
   TileManager *buf_tiles;
   PixelRegion  bufPR;
@@ -442,10 +462,42 @@ edit_fill (GImage       *gimage,
   if (!gimage || drawable == NULL)
     return FALSE;
 
-  gimage_get_background (gimage, drawable, col);
   if (drawable_has_alpha (drawable))
     col [drawable_bytes (drawable) - 1] = OPAQUE_OPACITY;
 
+  switch (fill_type)
+    {
+    case FOREGROUND_FILL:
+      gimage_get_foreground (gimage, drawable, col);
+      break;
+
+    case BACKGROUND_FILL:
+      gimage_get_background (gimage, drawable, col);
+      break;
+
+    case WHITE_FILL:
+      col[RED_PIX] = 255;
+      col[GREEN_PIX] = 255;
+      col[BLUE_PIX] = 255;
+      break;
+
+    case TRANSPARENT_FILL:
+      col[RED_PIX] = 0;
+      col[GREEN_PIX] = 0;
+      col[BLUE_PIX] = 0;
+      if (drawable_has_alpha (drawable))
+	col [drawable_bytes (drawable) - 1] = TRANSPARENT_OPACITY;
+      break;
+
+    case NO_FILL:
+      return TRUE;  /*  nothing to do, but the fill succeded  */
+
+    default:
+      g_warning ("unknown fill type");
+      gimage_get_background (gimage, drawable, col);
+      break;
+    }
+
   drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
 
   if (!(x2 - x1) || !(y2 - y1))
