@@ -17,13 +17,15 @@
  */
 #include "config.h"
 
+#include <glib.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
-#include "buildmenu.h"
 #include "drawable.h"
 #include "gdisplay.h"
 #include "gimpui.h"
 #include "histogram_tool.h"
-#include "image_map.h"
 
 #include "libgimp/gimpintl.h"
 #include "libgimp/gimpmath.h"
@@ -51,14 +53,12 @@ static void   histogram_tool_control (Tool *, ToolAction, gpointer);
 
 static HistogramToolDialog *  histogram_tool_dialog_new (void);
 
-static void   histogram_tool_close_callback  (GtkWidget *, gpointer);
-static void   histogram_tool_value_callback  (GtkWidget *, gpointer);
-static void   histogram_tool_red_callback    (GtkWidget *, gpointer);
-static void   histogram_tool_green_callback  (GtkWidget *, gpointer);
-static void   histogram_tool_blue_callback   (GtkWidget *, gpointer);
-static void   histogram_tool_gradient_draw   (GtkWidget *, gint);
+static void   histogram_tool_close_callback   (GtkWidget *, gpointer);
+static void   histogram_tool_channel_callback (GtkWidget *, gpointer);
+static void   histogram_tool_gradient_draw    (GtkWidget *, gint);
 
-static void   histogram_tool_dialog_update   (HistogramToolDialog *, gint, gint);
+static void   histogram_tool_dialog_update    (HistogramToolDialog *,
+					       gint, gint);
 
 /*  histogram_tool machinery  */
 
@@ -78,15 +78,17 @@ histogram_tool_histogram_range (HistogramWidget *widget,
       gimp_histogram_nchannels(htd->hist) <= 0)
     return;
 
-  pixels = gimp_histogram_get_count(htd->hist, 0, 255);
-  count = gimp_histogram_get_count(htd->hist, start, end);
+  pixels = gimp_histogram_get_count (htd->hist, 0, 255);
+  count  = gimp_histogram_get_count (htd->hist, start, end);
 
-  htd->mean = gimp_histogram_get_mean(htd->hist, htd->channel, start, end);
-  htd->std_dev = gimp_histogram_get_std_dev(htd->hist, htd->channel,
-					    start, end);
-  htd->median = gimp_histogram_get_median(htd->hist, htd->channel, start, end);
-  htd->pixels = pixels;
-  htd->count = count;
+  htd->mean       = gimp_histogram_get_mean (htd->hist, htd->channel,
+					     start, end);
+  htd->std_dev    = gimp_histogram_get_std_dev (htd->hist, htd->channel,
+						start, end);
+  htd->median     = gimp_histogram_get_median (htd->hist, htd->channel,
+					       start, end);
+  htd->pixels     = pixels;
+  htd->count      = count;
   htd->percentile = count / pixels;
 
   if (htd->shell)
@@ -171,7 +173,7 @@ tools_new_histogram_tool (void)
     }
 
   tool = tools_new_tool (HISTOGRAM);
-  private = g_new (HistogramTool, 1);
+  private = g_new0 (HistogramTool, 1);
 
   tool->scroll_lock = TRUE;   /*  Disallow scrolling  */
   tool->preserve    = FALSE;  /*  Don't preserve on drawable change  */
@@ -221,7 +223,20 @@ histogram_tool_initialize (GDisplay *gdisp)
   if (histogram_tool_dialog->color)
     gtk_widget_show (histogram_tool_dialog->channel_menu);
   else
-    gtk_widget_hide (histogram_tool_dialog->channel_menu);
+    {
+      /* Channels can only have value histograms; reconfigure channel menu. */
+      /* Note: gimp_histogram_get_mean() in gimphistogram.c. garo 5/7/2001  */ 
+      histogram_tool_dialog->channel = GIMP_HISTOGRAM_VALUE;
+      gimp_option_menu_set_history (g_list_nth_data 
+				    (gtk_container_children 
+				     (GTK_CONTAINER 
+				      (histogram_tool_dialog->channel_menu)), 
+				     1), 
+				    GINT_TO_POINTER (GIMP_HISTOGRAM_VALUE));
+      gtk_widget_hide (histogram_tool_dialog->channel_menu);
+      histogram_tool_gradient_draw (histogram_tool_dialog->gradient, 
+				    GIMP_HISTOGRAM_VALUE);
+    }
 
   /* calculate the histogram */
   pixel_region_init (&PR, drawable_data (histogram_tool_dialog->drawable), 0, 0,
@@ -251,7 +266,6 @@ histogram_tool_dialog_new (void)
   GtkWidget *table;
   GtkWidget *label;
   GtkWidget *option_menu;
-  GtkWidget *menu;
   gint i;
   gint x, y;
 
@@ -266,26 +280,14 @@ histogram_tool_dialog_new (void)
     N_("Percentile:")
   };
 
-  static MenuItem color_option_items[] =
-  {
-    { N_("Value"), 0, 0, histogram_tool_value_callback, NULL, NULL, NULL },
-    { N_("Red"), 0, 0, histogram_tool_red_callback, NULL, NULL, NULL },
-    { N_("Green"), 0, 0, histogram_tool_green_callback, NULL, NULL, NULL },
-    { N_("Blue"), 0, 0, histogram_tool_blue_callback, NULL, NULL, NULL },
-    { NULL, 0, 0, NULL, NULL, NULL, NULL }
-  };
-
   htd = g_new (HistogramToolDialog, 1);
-  htd->channel = HISTOGRAM_VALUE;
-
-  for (i = 0; i < 4; i++)
-    color_option_items [i].user_data = (gpointer) htd;
-
-  htd->hist = gimp_histogram_new ();
+  htd->channel = GIMP_HISTOGRAM_VALUE;
+  htd->hist    = gimp_histogram_new ();
 
   /*  The shell and main vbox  */
   htd->shell = gimp_dialog_new (_("Histogram"), "histogram",
-				tools_help_func, NULL,
+				tools_help_func,
+				tool_info[HISTOGRAM].private_tip,
 				GTK_WIN_POS_NONE,
 				FALSE, TRUE, FALSE,
 
@@ -310,15 +312,22 @@ histogram_tool_dialog_new (void)
 
   label = gtk_label_new (_("Information on Channel:"));
   gtk_box_pack_start (GTK_BOX (htd->channel_menu), label, FALSE, FALSE, 0);
-
-  menu = build_menu (color_option_items, NULL);
-  option_menu = gtk_option_menu_new ();
-  gtk_box_pack_start (GTK_BOX (htd->channel_menu), option_menu, FALSE, FALSE, 0);
-
   gtk_widget_show (label);
+
+  option_menu = gimp_option_menu_new2
+    (FALSE, histogram_tool_channel_callback,
+     htd, (gpointer) htd->channel,
+
+     _("Value"), GINT_TO_POINTER (GIMP_HISTOGRAM_VALUE), NULL,
+     _("Red"),   GINT_TO_POINTER (GIMP_HISTOGRAM_RED),   NULL,
+     _("Green"), GINT_TO_POINTER (GIMP_HISTOGRAM_GREEN), NULL,
+     _("Blue"),  GINT_TO_POINTER (GIMP_HISTOGRAM_BLUE),  NULL,
+
+     NULL);
+  gtk_box_pack_start (GTK_BOX (htd->channel_menu), option_menu, FALSE, FALSE, 0);
   gtk_widget_show (option_menu);
+
   gtk_widget_show (htd->channel_menu);
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
 
   /*  The histogram tool histogram  */
   frame = gtk_frame_new (NULL);
@@ -328,7 +337,7 @@ histogram_tool_dialog_new (void)
   htd->histogram = histogram_widget_new (HISTOGRAM_WIDTH, HISTOGRAM_HEIGHT);
   gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET(htd->histogram));
 
-  gtk_signal_connect (GTK_OBJECT (htd->histogram), "rangechanged",
+  gtk_signal_connect (GTK_OBJECT (htd->histogram), "range_changed",
 		      GTK_SIGNAL_FUNC (histogram_tool_histogram_range),
 		      htd);
 
@@ -349,7 +358,7 @@ histogram_tool_dialog_new (void)
   gtk_widget_show (htd->gradient);
   gtk_widget_show (frame);
   gtk_widget_show (grad_hbox);
-  histogram_tool_gradient_draw (htd->gradient, HISTOGRAM_VALUE);
+  histogram_tool_gradient_draw (htd->gradient, GIMP_HISTOGRAM_VALUE);
 
   gtk_widget_show (vbox);
   gtk_widget_show (hbox);
@@ -395,75 +404,24 @@ histogram_tool_close_callback (GtkWidget *widget,
 
   htd = (HistogramToolDialog *) data;
 
-  if (GTK_WIDGET_VISIBLE (htd->shell))
-    gtk_widget_hide (htd->shell);
-
+  gimp_dialog_hide (htd->shell);
+       
   active_tool->gdisp_ptr = NULL;
   active_tool->drawable = NULL;
 }
 
 static void
-histogram_tool_value_callback (GtkWidget *widget,
-			       gpointer   data)
+histogram_tool_channel_callback (GtkWidget *widget,
+				 gpointer   data)
 {
   HistogramToolDialog *htd;
 
   htd = (HistogramToolDialog *) data;
 
-  if (htd->channel != HISTOGRAM_VALUE)
-    {
-      htd->channel = HISTOGRAM_VALUE;
-      histogram_widget_channel (htd->histogram, htd->channel);
-      histogram_tool_gradient_draw (htd->gradient, HISTOGRAM_VALUE);
-    }
-}
+  gimp_menu_item_update (widget, &htd->channel);
 
-static void
-histogram_tool_red_callback (GtkWidget *widget,
-			     gpointer   data)
-{
-  HistogramToolDialog *htd;
-
-  htd = (HistogramToolDialog *) data;
-
-  if (htd->channel != HISTOGRAM_RED)
-    {
-      htd->channel = HISTOGRAM_RED;
-      histogram_widget_channel (htd->histogram, htd->channel);
-      histogram_tool_gradient_draw (htd->gradient, HISTOGRAM_RED);
-    }
-}
-
-static void
-histogram_tool_green_callback (GtkWidget *widget,
-			       gpointer   data)
-{
-  HistogramToolDialog *htd;
-
-  htd = (HistogramToolDialog *) data;
-
-  if (htd->channel != HISTOGRAM_GREEN)
-    {
-      htd->channel = HISTOGRAM_GREEN;
-      histogram_widget_channel (htd->histogram, htd->channel);
-      histogram_tool_gradient_draw (htd->gradient, HISTOGRAM_GREEN);
-    }
-}
-
-static void
-histogram_tool_blue_callback (GtkWidget *widget,
-			      gpointer   data)
-{
-  HistogramToolDialog *htd;
-
-  htd = (HistogramToolDialog *) data;
-
-  if (htd->channel != HISTOGRAM_BLUE)
-    {
-      htd->channel = HISTOGRAM_BLUE;
-      histogram_widget_channel (htd->histogram, htd->channel);
-      histogram_tool_gradient_draw (htd->gradient, HISTOGRAM_BLUE);
-    }
+  histogram_widget_channel (htd->histogram, htd->channel);
+  histogram_tool_gradient_draw (htd->gradient, htd->channel);
 }
 
 static void
@@ -475,16 +433,16 @@ histogram_tool_gradient_draw (GtkWidget *gradient,
   gint i;
 
   r = g = b = 0;
-  switch (channel) 
+  switch (channel)
     {
-    case HISTOGRAM_VALUE:
-    case HISTOGRAM_ALPHA:  r = g = b = 1; 
+    case GIMP_HISTOGRAM_VALUE:
+    case GIMP_HISTOGRAM_ALPHA:  r = g = b = 1;
       break;
-    case HISTOGRAM_RED:    r = 1;         
+    case GIMP_HISTOGRAM_RED:    r = 1;
       break;
-    case HISTOGRAM_GREEN:  g = 1;         
+    case GIMP_HISTOGRAM_GREEN:  g = 1;
       break;
-    case HISTOGRAM_BLUE:   b = 1;        
+    case GIMP_HISTOGRAM_BLUE:   b = 1;
       break;
     default:
       g_warning ("unknown channel type, can't happen\n");
