@@ -15,8 +15,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include "config.h"
 
+#include <glib.h>
+
+#include "apptypes.h"
+ 
 #include "appenv.h"
 #include "drawable.h"
 #include "gdisplay.h"
@@ -91,8 +96,7 @@ posterize_control (Tool       *tool,
       break;
 
     case HALT:
-      if (posterize_dialog)
-	posterize_cancel_callback (NULL, (gpointer) posterize_dialog);
+      posterize_dialog_hide ();
       break;
 
     default:
@@ -109,12 +113,12 @@ tools_new_posterize (void)
   /*  The tool options  */
   if (! posterize_options)
     {
-      posterize_options = tool_options_new (("Posterize"));
+      posterize_options = tool_options_new (_("Posterize"));
       tools_register (POSTERIZE, posterize_options);
     }
 
   tool = tools_new_tool (POSTERIZE);
-  private = g_new (Posterize, 1);
+  private = g_new0 (Posterize, 1);
 
   tool->scroll_lock = TRUE;   /*  Disallow scrolling  */
   tool->preserve    = FALSE;  /*  Don't preserve on drawable change  */
@@ -126,6 +130,13 @@ tools_new_posterize (void)
   return tool;
 }
 
+void
+posterize_dialog_hide (void)
+{
+  if (posterize_dialog)
+    posterize_cancel_callback (NULL, (gpointer) posterize_dialog);
+}
+
 void
 tools_free_posterize (Tool *tool)
 {
@@ -134,8 +145,7 @@ tools_free_posterize (Tool *tool)
   post = (Posterize *) tool->private;
 
   /*  Close the posterize dialog  */
-  if (posterize_dialog)
-    posterize_cancel_callback (NULL, (gpointer) posterize_dialog);
+  posterize_dialog_hide ();
 
   g_free (post);
 }
