@@ -15,8 +15,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
 #include <stdlib.h>
-#include "gdk/gdkkeysyms.h"
+
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "gdisplay.h"
 #include "gimage_mask.h"
@@ -27,10 +35,11 @@
 #include "selection_options.h"
 #include "cursorutil.h"
 
-#include "config.h"
 #include "libgimp/gimpunitmenu.h"
+
 #include "libgimp/gimpintl.h"
 
+
 #define STATUSBAR_SIZE 128
 
 
@@ -39,25 +48,36 @@ static SelectionOptions *rect_options = NULL;
 
 /*  in gimp, ellipses are rectangular, too ;)  */
 extern SelectionOptions *ellipse_options;
-extern void ellipse_select (GImage *, int, int, int, int, int, int, int, double);
+extern void ellipse_select (GimpImage *gimage,
+			    gint       x,
+			    gint       y,
+			    gint       w,
+			    gint       h,
+			    SelectOps  op,
+			    gboolean   antialias,
+			    gboolean   feather,
+			    gdouble    feather_radius);
 
-static void selection_tool_update_op_state(RectSelect *rect_sel, int x, int y,
-					   int state,  GDisplay *gdisp);
+static void selection_tool_update_op_state (RectSelect *rect_sel,
+					    gint        x,
+					    gint        y,
+					    gint        state, 
+					    GDisplay   *gdisp);
 
 /*************************************/
 /*  Rectangular selection apparatus  */
 
 void
 rect_select (GimpImage *gimage,
-	     int        x,
-	     int        y,
-	     int        w,
-	     int        h,
-	     int        op,
-	     int        feather,
-	     double     feather_radius)
+	     gint       x,
+	     gint       y,
+	     gint       w,
+	     gint       h,
+	     SelectOps  op,
+	     gboolean   feather,
+	     gdouble    feather_radius)
 {
-  Channel * new_mask;
+  Channel *new_mask;
 
   /*  if applicable, replace the current selection  */
   if (op == SELECTION_REPLACE)
@@ -111,14 +131,14 @@ rect_select_button_press (Tool           *tool,
   switch (tool->type)
     {
     case RECT_SELECT:
-      rect_sel->fixed_size = rect_options->fixed_size;
-      rect_sel->fixed_width = rect_options->fixed_width;
+      rect_sel->fixed_size   = rect_options->fixed_size;
+      rect_sel->fixed_width  = rect_options->fixed_width;
       rect_sel->fixed_height = rect_options->fixed_height;
       unit = rect_options->fixed_unit;
       break;
     case ELLIPSE_SELECT:
-      rect_sel->fixed_size = ellipse_options->fixed_size;
-      rect_sel->fixed_width = ellipse_options->fixed_width;
+      rect_sel->fixed_size   = ellipse_options->fixed_size;
+      rect_sel->fixed_width  = ellipse_options->fixed_width;
       rect_sel->fixed_height = ellipse_options->fixed_height;
       unit = ellipse_options->fixed_unit;
       break;
@@ -145,7 +165,7 @@ rect_select_button_press (Tool           *tool,
       break;
     }
 
-  rect_sel->fixed_width = MAX (1, rect_sel->fixed_width);
+  rect_sel->fixed_width  = MAX (1, rect_sel->fixed_width);
   rect_sel->fixed_height = MAX (1, rect_sel->fixed_height);
 
   rect_sel->w = 0;
@@ -154,7 +174,8 @@ rect_select_button_press (Tool           *tool,
   rect_sel->center = FALSE;
 
   gdk_pointer_grab (gdisp->canvas->window, FALSE,
-		    GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON1_MOTION_MASK |
+		    GDK_POINTER_MOTION_HINT_MASK |
+		    GDK_BUTTON1_MOTION_MASK |
 		    GDK_BUTTON_RELEASE_MASK,
 		    NULL, NULL, bevent->time);
 
@@ -164,10 +185,10 @@ rect_select_button_press (Tool           *tool,
   switch (rect_sel->op)
     {
     case SELECTION_MOVE_MASK:
-      init_edit_selection (tool, gdisp_ptr, bevent, MaskTranslate);
+      init_edit_selection (tool, gdisp_ptr, bevent, EDIT_MASK_TRANSLATE);
       return;
     case SELECTION_MOVE:
-      init_edit_selection (tool, gdisp_ptr, bevent, MaskToLayerTranslate);
+      init_edit_selection (tool, gdisp_ptr, bevent, EDIT_MASK_TO_LAYER_TRANSLATE);
       return;
     default:
       break;
@@ -204,9 +225,11 @@ rect_select_button_release (Tool           *tool,
 			    GdkEventButton *bevent,
 			    gpointer        gdisp_ptr)
 {
-  RectSelect * rect_sel;
-  GDisplay * gdisp;
-  int x1, y1, x2, y2, w, h;
+  RectSelect *rect_sel;
+  GDisplay   *gdisp;
+  gint x1, y1;
+  gint x2, y2;
+  gint w, h;
 
   gdisp = (GDisplay *) gdisp_ptr;
   rect_sel = (RectSelect *) tool->private;
@@ -275,20 +298,31 @@ rect_select_motion (Tool           *tool,
 		    GdkEventMotion *mevent,
 		    gpointer        gdisp_ptr)
 {
-  RectSelect * rect_sel;
-  GDisplay * gdisp;
-  gchar size[STATUSBAR_SIZE];
-  int ox, oy;
-  int x, y;
-  int w, h, s;
-  int tw, th;
-  double ratio;
+  RectSelect *rect_sel;
+  GDisplay   *gdisp;
+  gchar   size[STATUSBAR_SIZE];
+  gint    ox, oy;
+  gint    x, y;
+  gint    w, h, s;
+  gint    tw, th;
+  gdouble ratio;
+
+  gdisp = (GDisplay *) gdisp_ptr;
+  rect_sel = (RectSelect *) tool->private;
+
+  /*  needed for immediate cursor update on modifier event  */
+  rect_sel->current_x = mevent->x;
+  rect_sel->current_y = mevent->y;
 
   if (tool->state != ACTIVE)
     return;
 
-  gdisp = (GDisplay *) gdisp_ptr;
-  rect_sel = (RectSelect *) tool->private;
+  if (rect_sel->op == SELECTION_ANCHOR)
+    {
+      rect_sel->op = SELECTION_REPLACE;
+
+      rect_select_cursor_update (tool, mevent, gdisp_ptr);
+    }
 
   draw_core_pause (rect_sel->core, tool);
 
@@ -306,41 +340,47 @@ rect_select_motion (Tool           *tool,
     }
 
   gdisplay_untransform_coords (gdisp, mevent->x, mevent->y, &x, &y, TRUE, 0);
-  if (rect_sel->fixed_size) {
-    if (mevent->state & GDK_SHIFT_MASK) {
-      ratio = (double)(rect_sel->fixed_height /
-		       (double)rect_sel->fixed_width);
-      tw = x - ox;
-      th = y - oy;
-       /* 
-        * This is probably an inefficient way to do it, but it gives
-        * nicer, more predictable results than the original agorithm
-        */
+  if (rect_sel->fixed_size)
+    {
+      if (mevent->state & GDK_SHIFT_MASK)
+	{
+	  ratio = (double)(rect_sel->fixed_height /
+			   (double)rect_sel->fixed_width);
+	  tw = x - ox;
+	  th = y - oy;
+	  /* 
+	   * This is probably an inefficient way to do it, but it gives
+	   * nicer, more predictable results than the original agorithm
+	   */
  
-       if ((abs(th) < (ratio * abs(tw))) && (abs(tw) > (abs(th) / ratio)))
-         {
-           w = tw;
-           h = (int)(tw * ratio);
-           /* h should have the sign of th */
-           if ((th < 0 && h > 0) || (th > 0 && h < 0))
-             h = -h;
-         } 
-       else 
-         {
-           h = th;
-           w = (int)(th / ratio);
-           /* w should have the sign of tw */
-           if ((tw < 0 && w > 0) || (tw > 0 && w < 0))
-             w = -w;
-         }
-     } else {
-       w = (x - ox > 0 ? rect_sel->fixed_width  : -rect_sel->fixed_width);
-       h = (y - oy > 0 ? rect_sel->fixed_height : -rect_sel->fixed_height);
-     }
-  } else {
-    w = (x - ox);
-    h = (y - oy);
-  }
+	  if ((abs(th) < (ratio * abs(tw))) && (abs(tw) > (abs(th) / ratio)))
+	    {
+	      w = tw;
+	      h = (int)(tw * ratio);
+	      /* h should have the sign of th */
+	      if ((th < 0 && h > 0) || (th > 0 && h < 0))
+		h = -h;
+	    } 
+	  else 
+	    {
+	      h = th;
+	      w = (int)(th / ratio);
+	      /* w should have the sign of tw */
+	      if ((tw < 0 && w > 0) || (tw > 0 && w < 0))
+		w = -w;
+	    }
+	}
+      else
+	{
+	  w = (x - ox > 0 ? rect_sel->fixed_width  : -rect_sel->fixed_width);
+	  h = (y - oy > 0 ? rect_sel->fixed_height : -rect_sel->fixed_height);
+	}
+    }
+  else
+    {
+      w = (x - ox);
+      h = (y - oy);
+    }
 
   /*  If the shift key is down, then make the rectangle square (or ellipse circular) */
   if ((mevent->state & GDK_SHIFT_MASK) && !rect_sel->fixed_size)
@@ -348,14 +388,14 @@ rect_select_motion (Tool           *tool,
       s = MAX (abs (w), abs (h));
 	  
       if (w < 0)
-		w = -s;
+	w = -s;
       else
-		w = s;
+	w = s;
 
       if (h < 0)
-		h = -s;
+	h = -s;
       else
-		h = s;
+	h = s;
     }
 
   /*  If the control key is down, create the selection from the center out */
@@ -427,9 +467,10 @@ rect_select_motion (Tool           *tool,
 void
 rect_select_draw (Tool *tool)
 {
-  GDisplay * gdisp;
-  RectSelect * rect_sel;
-  int x1, y1, x2, y2;
+  GDisplay   *gdisp;
+  RectSelect *rect_sel;
+  gint x1, y1;
+  gint x2, y2;
 
   gdisp = (GDisplay *) tool->gdisp_ptr;
   rect_sel = (RectSelect *) tool->private;
@@ -449,32 +490,59 @@ rect_select_draw (Tool *tool)
 
 static void
 selection_tool_update_op_state (RectSelect *rect_sel,
-				int         x,
-				int         y,
-				int         state,  
+				gint        x,
+				gint        y,
+				gint        state,  
 				GDisplay   *gdisp)
 {
+  Layer *layer;
+  Layer *floating_sel;
+  gint   tx, ty;
+
   if (active_tool->state == ACTIVE)
     return;
 
+  gdisplay_untransform_coords (gdisp, x, y, &tx, &ty, FALSE, FALSE);
+
+  layer = gimage_pick_correlate_layer (gdisp->gimage, tx, ty);
+  floating_sel = gimage_floating_sel (gdisp->gimage);
+
   if (state & GDK_MOD1_MASK &&
-      !(layer_is_floating_sel (gimage_get_active_layer (gdisp->gimage))))
-    rect_sel->op = SELECTION_MOVE_MASK;  /* move just the selection mask */
-  else if (layer_is_floating_sel (gimage_get_active_layer (gdisp->gimage)) || 
-	   (!(state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) &&
-	    gdisplay_mask_value (gdisp, x, y)))
-    rect_sel->op = SELECTION_MOVE;      /* move the selection */
+      !gimage_mask_is_empty (gdisp->gimage))
+    {
+      rect_sel->op = SELECTION_MOVE_MASK; /* move just the selection mask */
+    }
+  else if (!(state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) &&
+	   layer &&
+	   (layer == floating_sel ||
+	    (gdisplay_mask_value (gdisp, x, y) &&
+	     floating_sel == NULL)))
+    {
+      rect_sel->op = SELECTION_MOVE;      /* move the selection */
+    }
   else if ((state & GDK_SHIFT_MASK) &&
 	   !(state & GDK_CONTROL_MASK))
-    rect_sel->op = SELECTION_ADD;       /* add to the selection */
+    {
+      rect_sel->op = SELECTION_ADD;       /* add to the selection */
+    }
   else if ((state & GDK_CONTROL_MASK) &&
 	   !(state & GDK_SHIFT_MASK))
-    rect_sel->op = SELECTION_SUB;      /* subtract from the selection */
+    {
+      rect_sel->op = SELECTION_SUB;       /* subtract from the selection */
+    }
   else if ((state & GDK_CONTROL_MASK) &&
 	   (state & GDK_SHIFT_MASK))
-    rect_sel->op = SELECTION_INTERSECT;/* intersect with selection */
+    {
+      rect_sel->op = SELECTION_INTERSECT; /* intersect with selection */
+    }
+  else if (floating_sel)
+    {
+      rect_sel->op = SELECTION_ANCHOR;    /* anchor the selection */
+    }
   else
-    rect_sel->op = SELECTION_REPLACE;  /* replace the selection */
+    {
+      rect_sel->op = SELECTION_REPLACE;   /* replace the selection */
+    }
 }
 
 void
@@ -484,43 +552,114 @@ rect_select_oper_update  (Tool           *tool,
 {
   RectSelect *rect_sel;
 
-  rect_sel = (RectSelect*)tool->private;
-  selection_tool_update_op_state (rect_sel, mevent->x, mevent->y,
+  rect_sel = (RectSelect *) tool->private;
+
+  rect_sel->current_x = mevent->x;
+  rect_sel->current_y = mevent->y;
+
+  selection_tool_update_op_state (rect_sel,
+				  rect_sel->current_x,
+				  rect_sel->current_y,
 				  mevent->state, gdisp_ptr);
 }
 
+void
+rect_select_modifier_update (Tool        *tool,
+			     GdkEventKey *kevent,
+			     gpointer     gdisp_ptr)
+{
+  RectSelect *rect_sel;
+  gint state;
+
+  state = kevent->state;
+
+  switch (kevent->keyval)
+    {
+    case GDK_Alt_L: case GDK_Alt_R:
+      if (state & GDK_MOD1_MASK)
+	state &= ~GDK_MOD1_MASK;
+      else
+	state |= GDK_MOD1_MASK;
+      break;
+
+    case GDK_Shift_L: case GDK_Shift_R:
+      if (state & GDK_SHIFT_MASK)
+	state &= ~GDK_SHIFT_MASK;
+      else
+	state |= GDK_SHIFT_MASK;
+      break;
+
+    case GDK_Control_L: case GDK_Control_R:
+      if (state & GDK_CONTROL_MASK)
+	state &= ~GDK_CONTROL_MASK;
+      else
+	state |= GDK_CONTROL_MASK;
+      break;
+    }
+
+  rect_sel = (RectSelect *) tool->private;
+  selection_tool_update_op_state (rect_sel,
+				  rect_sel->current_x,
+				  rect_sel->current_y,
+				  state, gdisp_ptr);
+}
+
 void
 rect_select_cursor_update (Tool           *tool,
 			   GdkEventMotion *mevent,
 			   gpointer        gdisp_ptr)
 {
-  int active;
   RectSelect *rect_sel;
-  GDisplay *gdisp;
-  gdisp = (GDisplay *)gdisp_ptr;
-  active = (active_tool->state == ACTIVE);
-  rect_sel = (RectSelect*)tool->private;
+  GDisplay   *gdisp;
+
+  rect_sel = (RectSelect *) tool->private;
+  gdisp = (GDisplay *) gdisp_ptr;
 
   switch (rect_sel->op)
-  {
-   case SELECTION_ADD:
-     gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1P_CURSOR);
-     break;
-   case SELECTION_SUB:
-     gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1M_CURSOR);
-     break;
-   case SELECTION_INTERSECT: 
-     gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1U_CURSOR);
-     break;
-   case SELECTION_REPLACE:
-     gdisplay_install_tool_cursor (gdisp, GDK_TCROSS);
-     break;
-   case SELECTION_MOVE_MASK:
-     gdisplay_install_tool_cursor (gdisp, GDK_DIAMOND_CROSS);
-     break;
-   case SELECTION_MOVE: 
-     gdisplay_install_tool_cursor (gdisp, GDK_FLEUR);
-  }
+    {
+    case SELECTION_ADD:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_PLUS,
+				    FALSE);
+      break;
+    case SELECTION_SUB:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_MINUS,
+				    FALSE);
+      break;
+    case SELECTION_INTERSECT: 
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_INTERSECT,
+				    FALSE);
+      break;
+    case SELECTION_REPLACE:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_NONE,
+				    FALSE);
+      break;
+    case SELECTION_MOVE_MASK:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_MOVE,
+				    FALSE);
+      break;
+    case SELECTION_MOVE:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    MOVE,
+				    CURSOR_MODIFIER_NONE,
+				    FALSE);
+      break;
+    case SELECTION_ANCHOR:
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    tool->type,
+				    CURSOR_MODIFIER_ANCHOR,
+				    FALSE);
+      break;
+    }
 }
 
 void
@@ -528,21 +667,21 @@ rect_select_control (Tool       *tool,
 		     ToolAction  action,
 		     gpointer    gdisp_ptr)
 {
-  RectSelect * rect_sel;
+  RectSelect *rect_sel;
 
   rect_sel = (RectSelect *) tool->private;
 
   switch (action)
     {
-    case PAUSE :
+    case PAUSE:
       draw_core_pause (rect_sel->core, tool);
       break;
 
-    case RESUME :
+    case RESUME:
       draw_core_resume (rect_sel->core, tool);
       break;
 
-    case HALT :
+    case HALT:
       draw_core_stop (rect_sel->core, tool);
       break;
 
@@ -552,13 +691,13 @@ rect_select_control (Tool       *tool,
 }
 
 static void
-rect_select_options_reset ()
+rect_select_options_reset (void)
 {
   selection_options_reset (rect_options);
 }
 
 Tool *
-tools_new_rect_select ()
+tools_new_rect_select (void)
 {
   Tool * tool;
   RectSelect * private;
@@ -572,7 +711,7 @@ tools_new_rect_select ()
     }
 
   tool = tools_new_tool (RECT_SELECT);
-  private = g_new (RectSelect, 1);
+  private = g_new0 (RectSelect, 1);
 
   private->core = draw_core_new (rect_select_draw);
   private->x = private->y = 0;
@@ -584,6 +723,7 @@ tools_new_rect_select ()
   tool->button_press_func   = rect_select_button_press;
   tool->button_release_func = rect_select_button_release;
   tool->motion_func         = rect_select_motion;
+  tool->modifier_key_func   = rect_select_modifier_update;
   tool->cursor_update_func  = rect_select_cursor_update;
   tool->oper_update_func    = rect_select_oper_update;
   tool->control_func        = rect_select_control;
