@@ -16,6 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include "config.h"
 
 #include <glib.h>
@@ -28,6 +29,8 @@
 #include <unistd.h>
 #endif
 
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "gdisplay_ops.h"
 #include "gimprc.h"
@@ -968,13 +971,14 @@ user_install_run (void)
   if (executable)
     {
 #ifdef G_OS_WIN32
-      char *quoted_data_dir, *quoted_user_dir;
+      char *quoted_data_dir, *quoted_user_dir, *quoted_sysconf_dir;
 
       /* On Windows, it is common for the GIMP data directory
        * to have spaces in it ("c:\Program Files\GIMP"). Put spaces in quotes.
        */
       quoted_data_dir = quote_spaces (gimp_data_directory ());
       quoted_user_dir = quote_spaces (gimp_directory ());
+      quoted_sysconf_dir = quote_spaces (gimp_sysconf_directory ());
 
       /* The Microsoft _popen doesn't work in Windows applications, sigh.
        * Do the installation by calling system(). The user_install.bat
@@ -984,14 +988,15 @@ user_install_run (void)
        */
 
       AllocConsole ();
-      g_snprintf (buffer, sizeof(buffer), "%s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s",
+      g_snprintf (buffer, sizeof(buffer), "%s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s %s",
 		  quoted_data_dir, quoted_data_dir,
-		  quoted_user_dir);
+		  quoted_user_dir, quoted_sysconf_dir);
 
       if (system (buffer) == -1)
 	executable = FALSE;
       g_free (quoted_data_dir);
       g_free (quoted_user_dir);
+      g_free (quoted_sysconf_dir);
 
       if (executable)
 	add_label (GTK_BOX (log_page),
@@ -1000,14 +1005,14 @@ user_install_run (void)
 		     "Otherwise, quit and investigate the possible reason..."));
 #else
 #ifndef __EMX__
-      g_snprintf (buffer, sizeof(buffer), "%s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s %s",
+      g_snprintf (buffer, sizeof(buffer), "%s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s %s %s",
 		  gimp_data_directory (),
 		  "2>&1",
-		  gimp_data_directory(), gimp_directory ());
+		  gimp_data_directory(), gimp_directory (), gimp_sysconf_directory());
 #else
-      g_snprintf (buffer, sizeof(buffer), "cmd.exe /c %s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s",
+      g_snprintf (buffer, sizeof(buffer), "cmd.exe /c %s" G_DIR_SEPARATOR_S USER_INSTALL " %s %s %s",
 		  gimp_data_directory (), gimp_data_directory(),
-		  gimp_directory ());
+		  gimp_directory (), gimp_sysconf_directory());
       {
 	char *s = buffer + 10;
 	while (*s)
@@ -1090,7 +1095,7 @@ user_install_tuning (void)
   /*  tile cache size  */
   add_label (GTK_BOX (tuning_page),
 	     _("GIMP uses a limited amount of memory to store image data, the so-called\n"
-	       "\"Tile Cache\". You should adjust it's size to fit into memory. Consider\n"
+	       "\"Tile Cache\". You should adjust its size to fit into memory. Consider\n"
 	       "the amount of memory used by other running processes."));
 
   hbox = gtk_hbox_new (FALSE, 8);
@@ -1287,7 +1292,8 @@ user_install_resolution_done (void)
       tile_cache_size = new_tile_cache_size;
       update = g_list_append (update, "tile-cache-size");
     }
-  if (strcmp (swap_path, new_swap_path))
+  if (swap_path && new_swap_path && 
+      strcmp (swap_path, new_swap_path))
     {
       g_free (swap_path);      swap_path = new_swap_path;
       update = g_list_append (update, "swap-path");
