@@ -260,7 +260,8 @@ save_image (gchar  *filename,
   gchar *ext;
   gchar *tmpname;
   gint   pid;
-  gint   status;
+  gint   wpid;
+  gint   process_status;
 
   if (NULL == (ext = find_extension (filename)))
     {
@@ -319,10 +320,11 @@ save_image (gchar  *filename,
     }
 #endif
     {
-      waitpid (pid, &status, 0);
+      wpid = waitpid (pid, &process_status, 0);
 
-      if (!WIFEXITED(status) ||
-	  WEXITSTATUS(status) != 0)
+      if ((wpid < 0)
+	  || !WIFEXITED (process_status)
+	  || (WEXITSTATUS (process_status) != 0))
 	{
 	  g_message ("bz2: bzip2 exited abnormally on file %s\n", tmpname);
 	  g_free (tmpname);
@@ -345,6 +347,7 @@ load_image (gchar             *filename,
   gchar  *ext;
   gchar  *tmpname;
   gint    pid;
+  gint    wpid;
   gint    process_status;
 
   if (NULL == (ext = find_extension (filename)))
@@ -389,7 +392,7 @@ load_image (gchar             *filename,
     }
   else  /* parent process */
 #else /* __EMX__ */
-  if (spawn_bz (filename, tmpname, "-cfd", &pid) == -1) 
+  if (spawn_bz (tmpname, filename,"-cfd", &pid) == -1) 
     {
       g_free (tmpname);
       *status = GIMP_PDB_EXECUTION_ERROR;
@@ -397,10 +400,11 @@ load_image (gchar             *filename,
     }
 #endif
     {
-      waitpid (pid, &process_status, 0);
+      wpid = waitpid (pid, &process_status, 0);
 
-      if (!WIFEXITED (process_status) ||
-	  WEXITSTATUS (process_status) != 0)
+      if ((wpid < 0)
+	  || !WIFEXITED (process_status)
+	  || (WEXITSTATUS (process_status) != 0))
 	{
 	  g_message ("bz2: bzip2 exited abnormally on file %s\n", filename);
 	  g_free (tmpname);
@@ -448,30 +452,29 @@ find_extension (gchar* filename)
   gchar *ext;
 
   /* we never free this copy - aren't we evil! */
-  filename_copy = g_malloc (strlen (filename) + 1);
-  strcpy (filename_copy, filename);
+  filename_copy = g_strdup (filename);
 
   /* find the extension, boy! */
   ext = strrchr (filename_copy, '.');
 
-  while (1)
+  while (TRUE)
     {
-      if (!ext || ext[1] == 0 || strchr (ext, '/'))
+      if (!ext || ext[1] == '\0' || strchr (ext, '/'))
 	{
 	  return NULL;
 	}
-      if (0 == strcmp (ext, ".xcfbz2"))
+      if (0 == g_strcasecmp (ext, ".xcfbz2"))
 	{
 	  return ".xcf";  /* we've found it */
 	}
-      if (0 != strcmp (ext, ".bz2"))
+      if (0 != g_strcasecmp (ext, ".bz2"))
 	{
 	  return ext;
 	}
       else
 	{
 	  /* we found ".bz2" so strip it, loop back, and look again */
-	  *ext = 0;
+	  *ext = '\0';
 	  ext = strrchr (filename_copy, '.');
 	}
     }
