@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* $Id: pnm.c,v 1.24 2000/08/24 14:17:32 neo Exp $ */
+/* $Id: pnm.c,v 1.26 2000/12/17 16:50:00 mitch Exp $ */
 
 /*
  * The pnm reading and writing code was written from scratch by Erik Nygren
@@ -38,9 +38,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-
-#include <gtk/gtk.h>
 
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
@@ -449,7 +446,7 @@ load_image (gchar *filename)
   CHECK_FOR_ERROR(pnmscanner_eof(scan), pnminfo->jmpbuf,
 		  _("PNM: Premature end of file."));
   CHECK_FOR_ERROR((buf[0] != 'P' || buf[2]), pnminfo->jmpbuf,
-		  _("PNM: %s is not a valid file."));
+		  _("PNM: Invalid file."));
 
   /* Look up magic number to see what type of PNM this is */
   for (ctr=0; pnm_types[ctr].name; ctr++)
