@@ -1,20 +1,10 @@
-/*  
- *  Rotate plug-in v0.9 
- *  by Sven Neumann <sven@gimp.org> and Adam D. Moss <adam@gimp.org>
- *
- *  Any suggestions, bug-reports or patches are very welcome.
- * 
- *  A lot of changes in version 0.3 were inspired by (or even simply 
- *  copied from) the similar rotators-plug-in by Adam D. Moss. 
- *
- *  As I still prefer my version I have not stopped developing it.
- *  Probably this will result in one plug-in that includes the advantages 
- *  of both approaches.
- */
-
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
+ *  Rotate plug-in v1.0
+ *  Copyright 1997-2000 by Sven Neumann <sven@gimp.org> 
+ *                       & Adam D. Moss <adam@gimp.org>
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -44,6 +34,8 @@
  *  (10/09/99)  v0.8   rotate guides too
  *  (11/13/99)  v0.9   merge rotators and rotate plug-ins 
  *                     -> drop the dialog, register directly into menus instead
+ *  (06/18/00)  v1.0   speed up 180 rotations, 
+ *                     declare version 1.0 for gimp-1.2 release
  */
 
 /* TODO List
@@ -57,6 +49,7 @@
 #include "config.h"
 
 #include <stdlib.h>
+#include <string.h>
 
 #include <libgimp/gimp.h>
 
@@ -64,7 +57,7 @@
 
 
 /* Defines */
-#define PLUG_IN_VERSION     "v0.9 (1999/11/13)"
+#define PLUG_IN_VERSION     "v1.0 (2000/06/18)"
 #define PLUG_IN_IMAGE_TYPES "RGB*, INDEXED*, GRAY*"
 #define PLUG_IN_AUTHOR      "Sven Neumann <sven@gimp.org>, Adam D. Moss <adam@gimp.org>"
 #define PLUG_IN_COPYRIGHT   "Sven Neumann, Adam D. Moss"
@@ -91,23 +84,23 @@ static RotateValues rotvals =
 
 
 static void  query   (void);
-static void  run     (gchar   *name,
-		      gint     nparams,	
-		      GParam  *param,	
-		      gint    *nreturn_vals,  
-		      GParam **return_vals);
+static void  run     (gchar      *name,
+		      gint        nparams,	
+		      GimpParam  *param,	
+		      gint       *nreturn_vals,  
+		      GimpParam **return_vals);
  
 static void  rotate                 (void);
-static void  rotate_drawable        (GDrawable *drawable);
-static void  rotate_compute_offsets (gint      *offsetx, 
-				     gint      *offsety, 
-				     gint       image_width, 
-				     gint       image_height,
-				     gint       width, 
-				     gint       height);
+static void  rotate_drawable        (GimpDrawable *drawable);
+static void  rotate_compute_offsets (gint         *offsetx, 
+				     gint         *offsety, 
+				     gint          image_width, 
+				     gint          image_height,
+				     gint          width, 
+				     gint          height);
 
 /* Global Variables */
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,	 /* quit_proc  */
@@ -116,8 +109,8 @@ GPlugInInfo PLUG_IN_INFO =
 };
 
 /* the image and drawable that will be used later */
-static GDrawable *active_drawable = NULL;
-static gint32     image_ID = -1;
+static GimpDrawable *active_drawable = NULL;
+static gint32        image_ID = -1;
 
 /* Functions */
 
@@ -126,21 +119,21 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef args[] =
+  static GimpParamDef args[] =
   {
-    { PARAM_INT32,    "run_mode",   "Interactive, non-interactive"},
-    { PARAM_IMAGE,    "image",      "Input image" },
-    { PARAM_DRAWABLE, "drawable",   "Input drawable" },
-    { PARAM_INT32,    "angle",      "Angle { 90 (1), 180 (2), 270 (3) } degrees" },
-    { PARAM_INT32,    "everything", "Rotate the whole image? { TRUE, FALSE }" }
+    { GIMP_PDB_INT32,    "run_mode",   "Interactive, non-interactive"},
+    { GIMP_PDB_IMAGE,    "image",      "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable",   "Input drawable" },
+    { GIMP_PDB_INT32,    "angle",      "Angle { 90 (1), 180 (2), 270 (3) } degrees" },
+    { GIMP_PDB_INT32,    "everything", "Rotate the whole image? { TRUE, FALSE }" }
   };
   static gint nargs = sizeof (args) / sizeof (args[0]);
 
-  static GParamDef menuargs[] =
+  static GimpParamDef menuargs[] =
   {
-    { PARAM_INT32,    "run_mode",   "Interactive, non-interactive" },
-    { PARAM_IMAGE,    "image",      "Input image" },
-    { PARAM_DRAWABLE, "drawable",   "Input drawable"}
+    { GIMP_PDB_INT32,    "run_mode",   "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE,    "image",      "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable",   "Input drawable"}
   };
   static gint nmenuargs = sizeof (menuargs) / sizeof (menuargs[0]);
 
@@ -155,7 +148,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  NULL,
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,		
+			  GIMP_PLUGIN,		
 			  nargs, 0,
 			  args, NULL);
 
@@ -167,7 +160,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Layers/Rotate/90 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
   gimp_install_procedure ("plug_in_layer_rot180",
@@ -178,7 +171,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Layers/Rotate/180 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
   gimp_install_procedure ("plug_in_layer_rot270",
@@ -189,7 +182,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Layers/Rotate/270 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
 
@@ -201,7 +194,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Image/Transforms/Rotate/90 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
   gimp_install_procedure ("plug_in_image_rot180",
@@ -212,7 +205,7 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Image/Transforms/Rotate/180 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
   gimp_install_procedure ("plug_in_image_rot270",
@@ -223,35 +216,35 @@ query (void)
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Image/Transforms/Rotate/270 degrees"),
 			  PLUG_IN_IMAGE_TYPES,
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nmenuargs, 0,
 			  menuargs, NULL);
 }
 
 static void 
-run (gchar    *name,
-     gint      nparams,
-     GParam   *param,
-     gint     *nreturn_vals,
-     GParam **return_vals)
+run (gchar      *name,
+     gint        nparams,
+     GimpParam  *param,
+     gint       *nreturn_vals,
+     GimpParam **return_vals)
 {
   /* Get the runmode from the in-parameters */
-  GRunModeType run_mode = param[0].data.d_int32;	
+  GimpRunModeType run_mode = param[0].data.d_int32;	
   
   /* status variable, use it to check for errors in invocation usualy only 
      during non-interactive calling */	
-  GStatusType status = STATUS_SUCCESS;	 
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;	 
   
   /*always return at least the status to the caller. */
-  static GParam values[1];
+  static GimpParam values[1];
   
   /* initialize the return of the status */ 	
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
   *nreturn_vals = 1;
   *return_vals = values;
 
-  INIT_I18N(); 
+  INIT_I18N (); 
 
   /* get image and drawable */
   image_ID = param[1].data.d_int32;
@@ -263,8 +256,8 @@ run (gchar    *name,
     {
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
-	case RUN_NONINTERACTIVE:
+	case GIMP_RUN_INTERACTIVE:
+	case GIMP_RUN_NONINTERACTIVE:
 	  /* check to see if invoked with the correct number of parameters */
 	  if (nparams == 5)
 	    {
@@ -275,9 +268,9 @@ run (gchar    *name,
 	      gimp_set_data ("plug_in_rotate", &rotvals, sizeof (RotateValues));
 	    }
 	  else
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  break;
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  /* Possibly retrieve data from a previous run */
 	  gimp_get_data ("plug_in_rotate", &rotvals);
 	  rotvals.angle = rotvals.angle % 4;
@@ -317,18 +310,19 @@ run (gchar    *name,
       rotvals.everything = TRUE;
     }
   else 
-    status = STATUS_CALLING_ERROR;
+    status = GIMP_PDB_CALLING_ERROR;
 
-  if (status == STATUS_SUCCESS)
+  if (status == GIMP_PDB_SUCCESS)
     {
       /* Run the main function */
       rotate ();
       
       /* If run mode is interactive, flush displays, else (script) don't 
 	 do it, as the screen updates would make the scripts slow */
-      if (run_mode != RUN_NONINTERACTIVE)
+      if (run_mode != GIMP_RUN_NONINTERACTIVE)
 	gimp_displays_flush ();
     }
+
   values[0].data.d_status = status; 
 }
 
@@ -374,14 +368,17 @@ rotate_compute_offsets (gint *offsetx,
 
 
 static void
-rotate_drawable (GDrawable *drawable)
+rotate_drawable (GimpDrawable *drawable)
 {
-  GPixelRgn srcPR, destPR;
-  gint width, height, longside, bytes;
-  gint row, col, byte;
-  gint offsetx, offsety;
-  gint was_preserve_transparency = FALSE;
-  guchar *buffer, *src_row, *dest_row;
+  GimpPixelRgn  srcPR, destPR;
+  gint          width, height;
+  gint          longside;
+  gint          bytes;
+  gint          row, col;
+  gint          offsetx, offsety;
+  gboolean      was_preserve_transparency = FALSE;
+  guchar       *buffer;
+  guchar       *src_row, *dest_row;
 
   /* initialize */
 
@@ -400,7 +397,7 @@ rotate_drawable (GDrawable *drawable)
 
   if (rotvals.angle == 2)  /* we're rotating by 180 */
     {
-      gimp_tile_cache_ntiles (2 * (width / gimp_tile_width()) + 1);
+      gimp_tile_cache_ntiles (2 * (width / gimp_tile_width() + 1));
 
       gimp_pixel_rgn_init (&srcPR, drawable, 0, 0, width, height, 
 			   FALSE, FALSE);
@@ -415,11 +412,9 @@ rotate_drawable (GDrawable *drawable)
 	  gimp_pixel_rgn_get_row (&srcPR, src_row, 0, row, width); 
 	  for (col = 0; col < width; col++) 
 	    { 
-	      for (byte = 0; byte < bytes; byte++)
-		{
-		  dest_row[col * bytes + byte] =  
-		    src_row[(width - col - 1) * bytes + byte];
-		}
+	      memcpy (dest_row + col * bytes, 
+		      src_row + (width - 1 - col) * bytes,
+		      bytes);
 	    } 	    
 	  gimp_pixel_rgn_set_row (&destPR, dest_row, 0, (height - row - 1), 
 				  width);
@@ -444,8 +439,8 @@ rotate_drawable (GDrawable *drawable)
       drawable = gimp_drawable_get (drawable->id);
       gimp_drawable_flush (drawable);
       
-      gimp_tile_cache_ntiles ( ((longside/gimp_tile_width())+1) + 
-			       ((longside/gimp_tile_height())+1) );
+      gimp_tile_cache_ntiles ( (longside / gimp_tile_width () + 1) + 
+			       (longside / gimp_tile_height () + 1) );
 
       gimp_pixel_rgn_init (&srcPR, drawable, 0, 0, longside, longside, 
 			   FALSE, FALSE);
@@ -511,14 +506,14 @@ rotate_drawable (GDrawable *drawable)
 static void 
 rotate (void)
 {
-  GDrawable *drawable;
-  gint32    *layers;
-  gint       i;
-  gint       nlayers;
-  gint32     guide_ID;
-  GuideInfo *guide;
-  GList     *guides = NULL;
-  GList     *list;
+  GimpDrawable *drawable;
+  gint32       *layers;
+  gint          i;
+  gint          nlayers;
+  gint32        guide_ID;
+  GuideInfo    *guide;
+  GList        *guides = NULL;
+  GList        *list;
 
   if (rotvals.angle == 0) return;  
 
@@ -600,7 +595,7 @@ rotate (void)
 	      for (list = guides; list; list = list->next)  
 		{
 		  guide = (GuideInfo *)list->data;
-		  if (guide->orientation == ORIENTATION_HORIZONTAL)
+		  if (guide->orientation == GIMP_HORIZONTAL)
 		    gimp_image_add_vguide (image_ID, height - guide->position);
 		  else
 		    gimp_image_add_hguide (image_ID, guide->position);
@@ -611,7 +606,7 @@ rotate (void)
 	      for (list = guides; list; list = list->next)  
 		{
 		  guide = (GuideInfo *)list->data;
-		  if (guide->orientation == ORIENTATION_HORIZONTAL)
+		  if (guide->orientation == GIMP_HORIZONTAL)
 		    gimp_image_add_hguide (image_ID, height - guide->position);
 		  else
 		    gimp_image_add_vguide (image_ID, width - guide->position);
@@ -622,7 +617,7 @@ rotate (void)
 	      for (list = guides; list; list = list->next)  
 		{
 		  guide = (GuideInfo *)list->data;
-		  if (guide->orientation == ORIENTATION_HORIZONTAL)
+		  if (guide->orientation == GIMP_HORIZONTAL)
 		    gimp_image_add_vguide (image_ID, guide->position);
 		  else
 		    gimp_image_add_hguide (image_ID, width - guide->position);
