@@ -40,6 +40,7 @@
 
 #include "libgimp/stdplugins-intl.h"
 
+
 #define SCALE_WIDTH  175
 #define MAX_CHANNELS   4
 #define PSV            2  /* point spread value */
@@ -60,10 +61,10 @@ typedef struct
   gdouble opacity;
   gdouble random_hue;
   gdouble random_saturation;
-  gint preserve_luminosity;
-  gint invers;
-  gint border;
-  gint colortype;
+  gint    preserve_luminosity;
+  gint    invers;
+  gint    border;
+  gint    colortype;
 } SparkleVals;
 
 typedef struct
@@ -77,23 +78,23 @@ typedef struct
 static void      query  (void);
 static void      run    (gchar   *name,
 			 gint     nparams,
-			 GParam  *param,
+			 GimpParam  *param,
 			 gint    *nreturn_vals,
-			 GParam **return_vals);
+			 GimpParam **return_vals);
 
 static gint      sparkle_dialog        (void);
 static void      sparkle_ok_callback   (GtkWidget *widget,
 					gpointer   data);
 
-static gint      compute_luminosity    (guchar *   pixel,
+static gint      compute_luminosity    (guchar    *pixel,
 					gint       gray,
 					gint       has_alpha);
-static gint      compute_lum_threshold (GDrawable * drawable,
+static gint      compute_lum_threshold (GimpDrawable *drawable,
 					gdouble    percentile);
-static void      sparkle               (GDrawable * drawable,
+static void      sparkle               (GimpDrawable *drawable,
 					gint       threshold);
-static void      fspike                (GPixelRgn * src_rgn,
-					GPixelRgn * dest_rgn,
+static void      fspike                (GimpPixelRgn *src_rgn,
+					GimpPixelRgn *dest_rgn,
 					gint       gray,
 					gint       x1,
 					gint       y1,
@@ -106,8 +107,8 @@ static void      fspike                (GPixelRgn * src_rgn,
 					gdouble    inten,
 					gdouble    length,
 					gdouble    angle);
-static GTile*    rpnt                  (GDrawable * drawable,
-					GTile *    tile,
+static GimpTile*    rpnt                  (GimpDrawable *drawable,
+					GimpTile     *tile,
 					gint       x1,
 					gint       y1,
 					gint       x2,
@@ -116,13 +117,13 @@ static GTile*    rpnt                  (GDrawable * drawable,
 					gdouble    yr,
 					gint       tile_width,
 					gint       tile_height,
-					gint *     row,
-					gint *     col,
+					gint      *row,
+					gint      *col,
 					gint       bytes,
 					gdouble    inten,
-					guchar color[MAX_CHANNELS]);
+					guchar     color[MAX_CHANNELS]);
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -160,29 +161,27 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef args[] =
+  static GimpParamDef args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
-    { PARAM_FLOAT, "lum_threshold", "Luminosity threshold (0.0 - 1.0)" },
-    { PARAM_FLOAT, "flare_inten", "Flare intensity (0.0 - 1.0)" },
-    { PARAM_INT32, "spike_len", "Spike length (in pixels)" },
-    { PARAM_INT32, "spike_pts", "# of spike points" },
-    { PARAM_INT32, "spike_angle", "Spike angle (0-360 degrees, -1: random)" },
-    { PARAM_FLOAT, "density", "Spike density (0.0 - 1.0)" },
-    { PARAM_FLOAT, "opacity", "Opacity (0.0 - 1.0)" },
-    { PARAM_FLOAT, "random_hue", "Random hue (0.0 - 1.0)" },
-    { PARAM_FLOAT, "random_saturation", "Random saturation (0.0 - 1.0)" },
-    { PARAM_INT32, "preserve_luminosity", "Preserve luminosity (TRUE/FALSE)" },
-    { PARAM_INT32, "invers", "Invers (TRUE/FALSE)" },
-    { PARAM_INT32, "border", "Add border (TRUE/FALSE)" },
-    { PARAM_INT32, "colortype", "Color of sparkles: { NATURAL (0), FOREGROUND (1), BACKGROUND (2) }" }
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image (unused)" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
+    { GIMP_PDB_FLOAT, "lum_threshold", "Luminosity threshold (0.0 - 1.0)" },
+    { GIMP_PDB_FLOAT, "flare_inten", "Flare intensity (0.0 - 1.0)" },
+    { GIMP_PDB_INT32, "spike_len", "Spike length (in pixels)" },
+    { GIMP_PDB_INT32, "spike_pts", "# of spike points" },
+    { GIMP_PDB_INT32, "spike_angle", "Spike angle (0-360 degrees, -1: random)" },
+    { GIMP_PDB_FLOAT, "density", "Spike density (0.0 - 1.0)" },
+    { GIMP_PDB_FLOAT, "opacity", "Opacity (0.0 - 1.0)" },
+    { GIMP_PDB_FLOAT, "random_hue", "Random hue (0.0 - 1.0)" },
+    { GIMP_PDB_FLOAT, "random_saturation", "Random saturation (0.0 - 1.0)" },
+    { GIMP_PDB_INT32, "preserve_luminosity", "Preserve luminosity (TRUE/FALSE)" },
+    { GIMP_PDB_INT32, "invers", "Invers (TRUE/FALSE)" },
+    { GIMP_PDB_INT32, "border", "Add border (TRUE/FALSE)" },
+    { GIMP_PDB_INT32, "colortype", "Color of sparkles: { NATURAL (0), FOREGROUND (1), BACKGROUND (2) }" }
   };
   static gint nargs = sizeof (args) / sizeof (args[0]);
 
-  INIT_I18N();
-
   gimp_install_procedure ("plug_in_sparkle",
 			  "Simulates pixel bloom and diffraction effects",
 			  "No help yet",
@@ -191,7 +190,7 @@ query (void)
 			  "Version 1.26, December 1998",
 			  N_("<Image>/Filters/Light Effects/Sparkle..."),
 			  "RGB*, GRAY*",
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nargs, 0,
 			  args, NULL);
 }
@@ -199,14 +198,14 @@ query (void)
 static void
 run (gchar   *name,
      gint     nparams,
-     GParam  *param,
+     GimpParam  *param,
      gint    *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  static GParam values[1];
-  GDrawable *drawable;
-  GRunModeType run_mode;
-  GStatusType status = STATUS_SUCCESS;
+  static GimpParam values[1];
+  GimpDrawable *drawable;
+  GimpRunModeType run_mode;
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;
   gint threshold, x1, y1, x2, y2;
 
   run_mode = param[0].data.d_int32;
@@ -214,12 +213,12 @@ run (gchar   *name,
   *nreturn_vals = 1;
   *return_vals = values;
 
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
 
   switch (run_mode)
     {
-    case RUN_INTERACTIVE:
+    case GIMP_RUN_INTERACTIVE:
       INIT_I18N_UI();
       /*  Possibly retrieve data  */
       gimp_get_data ("plug_in_sparkle", &svals);
@@ -229,12 +228,12 @@ run (gchar   *name,
 	return;
       break;
 
-    case RUN_NONINTERACTIVE:
+    case GIMP_RUN_NONINTERACTIVE:
       INIT_I18N();
       /*  Make sure all the arguments are there!  */
       if (nparams != 16)
 	{
-	  status = STATUS_CALLING_ERROR;
+	  status = GIMP_PDB_CALLING_ERROR;
 	}
       else
 	{
@@ -253,30 +252,30 @@ run (gchar   *name,
 	  svals.colortype = param[15].data.d_int32;
 
 	  if (svals.lum_threshold < 0.0 || svals.lum_threshold > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.flare_inten < 0.0 || svals.flare_inten > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.spike_len < 0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.spike_pts < 0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.spike_angle < -1 || svals.spike_angle > 360)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.density < 0.0 || svals.density > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.opacity < 0.0 || svals.opacity > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.random_hue < 0.0 || svals.random_hue > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.random_saturation < 0.0 ||
 		   svals.random_saturation > 1.0)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	  else if (svals.colortype < NATURAL || svals.colortype > BACKGROUND)
-	    status = STATUS_CALLING_ERROR;
+	    status = GIMP_PDB_CALLING_ERROR;
 	}
       break;
 
-    case RUN_WITH_LAST_VALS:
+    case GIMP_RUN_WITH_LAST_VALS:
       INIT_I18N();
       /*  Possibly retrieve data  */
       gimp_get_data ("plug_in_sparkle", &svals);
@@ -290,7 +289,8 @@ run (gchar   *name,
   drawable = gimp_drawable_get (param[2].data.d_drawable);
 
   /*  Make sure that the drawable is gray or RGB color  */
-  if (gimp_drawable_is_rgb (drawable->id) || gimp_drawable_is_gray (drawable->id))
+  if (gimp_drawable_is_rgb (drawable->id) ||
+      gimp_drawable_is_gray (drawable->id))
     {
       gimp_progress_init (_("Sparkling..."));
       gimp_tile_cache_ntiles (2 * (drawable->width / gimp_tile_width () + 1));
@@ -307,17 +307,17 @@ run (gchar   *name,
           
       sparkle (drawable, threshold);
 
-      if (run_mode != RUN_NONINTERACTIVE)
+      if (run_mode != GIMP_RUN_NONINTERACTIVE)
 	gimp_displays_flush ();
 
       /*  Store mvals data  */
-      if (run_mode == RUN_INTERACTIVE)
+      if (run_mode == GIMP_RUN_INTERACTIVE)
 	gimp_set_data ("plug_in_sparkle", &svals, sizeof (SparkleVals));
     }
   else
     {
       /* gimp_message ("sparkle: cannot operate on indexed color images"); */
-      status = STATUS_EXECUTION_ERROR;
+      status = GIMP_PDB_EXECUTION_ERROR;
     }
 
   values[0].data.d_status = status;
@@ -338,18 +338,11 @@ sparkle_dialog (void)
   GtkWidget *sep;
   GtkWidget *r1, *r2, *r3;
   GtkObject *scale_data;
-  gchar **argv;
-  gint    argc;
 
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("sparkle");
-
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
+  gimp_ui_init ("sparkle", FALSE);
 
   dlg = gimp_dialog_new (_("Sparkle"), "sparkle",
-			 gimp_plugin_help_func, "filters/sparkle.html",
+			 gimp_standard_help_func, "filters/sparkle.html",
 			 GTK_WIN_POS_MOUSE,
 			 FALSE, TRUE, FALSE,
 
@@ -369,7 +362,7 @@ sparkle_dialog (void)
   /*  parameter settings  */
   frame = gtk_frame_new (_("Parameter Settings"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-  gtk_container_border_width (GTK_CONTAINER (frame), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), frame, TRUE, TRUE, 0);
   gtk_widget_show (frame);
 
@@ -491,8 +484,8 @@ sparkle_dialog (void)
 
   toggle = gtk_check_button_new_with_label (_("Preserve Luminosity"));
   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle),
-			       svals.preserve_luminosity);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
+				svals.preserve_luminosity);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
 		      GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 		      &svals.preserve_luminosity);
@@ -502,7 +495,7 @@ sparkle_dialog (void)
 
   toggle = gtk_check_button_new_with_label (_("Inverse"));
   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), svals.invers);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), svals.invers);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
 		      GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 		      &svals.invers);
@@ -511,7 +504,7 @@ sparkle_dialog (void)
 
   toggle = gtk_check_button_new_with_label (_("Add Border"));
   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
-  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), svals.border);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), svals.border);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
 		      GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 		      &svals.border);
@@ -594,19 +587,19 @@ compute_luminosity (guchar *pixel,
 }
 
 static gint
-compute_lum_threshold (GDrawable *drawable,
+compute_lum_threshold (GimpDrawable *drawable,
 		       gdouble    percentile)
 {
-  GPixelRgn src_rgn;
-  gpointer pr;
-  guchar *data;
-  gint values[256];
-  gint total, sum;
-  gint size;
-  gint gray;
-  gint has_alpha;
-  gint i;
-  gint x1, y1, x2, y2;
+  GimpPixelRgn src_rgn;
+  gpointer  pr;
+  guchar   *data;
+  gint      values[256];
+  gint      total, sum;
+  gint      size;
+  gint      gray;
+  gint      has_alpha;
+  gint      i;
+  gint      x1, y1, x2, y2;
 
   /*  zero out the luminosity values array  */
 
@@ -650,20 +643,20 @@ compute_lum_threshold (GDrawable *drawable,
 }
 
 static void
-sparkle (GDrawable *drawable,
+sparkle (GimpDrawable *drawable,
 	 gint       threshold)
 {
-  GPixelRgn src_rgn, dest_rgn;
-  guchar *src, *dest;
-  gdouble nfrac, length, inten, spike_angle;
-  gint cur_progress, max_progress;
-  gint x1, y1, x2, y2;
-  gint size, lum, x, y, b;
-  gint gray;
-  gint has_alpha, alpha;
-  gpointer pr;
-  guchar *tmp1;
-  gint tile_width, tile_height;
+  GimpPixelRgn src_rgn, dest_rgn;
+  guchar   *src, *dest;
+  gdouble   nfrac, length, inten, spike_angle;
+  gint      cur_progress, max_progress;
+  gint      x1, y1, x2, y2;
+  gint      size, lum, x, y, b;
+  gint      gray;
+  gint      has_alpha, alpha;
+  gpointer  pr;
+  guchar   *tmp1;
+  gint      tile_width, tile_height;
 
   gimp_drawable_mask_bounds (drawable->id, &x1, &y1, &x2, &y2);
   gray = gimp_drawable_is_gray (drawable->id);
@@ -783,9 +776,9 @@ sparkle (GDrawable *drawable,
   gimp_drawable_update (drawable->id, x1, y1, (x2 - x1), (y2 - y1));
 }
 
-static inline GTile *
-rpnt (GDrawable *drawable,
-      GTile     *tile,
+static inline GimpTile *
+rpnt (GimpDrawable *drawable,
+      GimpTile     *tile,
       gint       x1,
       gint       y1,
       gint       x2,
@@ -800,7 +793,7 @@ rpnt (GDrawable *drawable,
       gdouble    inten,
       guchar     color[MAX_CHANNELS])
 {
-  gint x, y, b;
+  gint    x, y, b;
   gdouble dx, dy, rs, val;
   guchar *pixel;
   gdouble new;
@@ -867,8 +860,8 @@ rpnt (GDrawable *drawable,
 }
 
 static void
-fspike (GPixelRgn *src_rgn,
-	GPixelRgn *dest_rgn,
+fspike (GimpPixelRgn *src_rgn,
+	GimpPixelRgn *dest_rgn,
 	gint       gray,
 	gint       x1,
 	gint       y1,
@@ -888,14 +881,14 @@ fspike (GPixelRgn *src_rgn,
   gdouble in;
   gdouble theta;
   gdouble sfac;
-  gint r, g, b;
-  GTile *tile = NULL;
-  gint row, col;
-  gint i;
-  gint bytes;
-  gint ok;
-  guchar pixel[MAX_CHANNELS];
-  guchar color[MAX_CHANNELS];
+  gint    r, g, b;
+  GimpTile  *tile = NULL;
+  gint    row, col;
+  gint    i;
+  gint    bytes;
+  gint    ok;
+  guchar  pixel[MAX_CHANNELS];
+  guchar  color[MAX_CHANNELS];
 
   theta = angle;
   bytes = dest_rgn->bpp;
@@ -926,9 +919,9 @@ fspike (GPixelRgn *src_rgn,
       
       if (svals.invers)
 	{
-	       color[0] = 255 - color[0];
-	       color[1] = 255 - color[1];
-	       color[2] = 255 - color[2];
+	  color[0] = 255 - color[0];
+	  color[1] = 255 - color[1];
+	  color[2] = 255 - color[2];
         }
       if (svals.random_hue > 0.0 || svals.random_saturation > 0.0)
         {
@@ -961,8 +954,8 @@ fspike (GPixelRgn *src_rgn,
 	  sfac = inten * exp (-pow (rpos / length, efac));
 	  ok = FALSE;
 
-        in = 0.2 * sfac;
-        if (in > 0.01)
+	  in = 0.2 * sfac;
+	  if (in > 0.01)
             ok = TRUE;
 
 	  tile = rpnt (dest_rgn->drawable, tile, x1, y1, x2, y2, xrt, yrt, tile_width, tile_height, &row, &col, bytes, in, color);
